@@ -10,6 +10,7 @@ import IconUndo from 'react-icons/lib/md/undo'
 import IconConfigure from 'react-icons/lib/md/settings'
 import ToolbarSaveButton from './toolbar-save-button';
 import ToolbarLoadButton from './toolbar-load-button';
+import ToolBarScreenshotButton from './toolbar-screenshot-button';
 
 import If from "../../utils/react-if";
 
@@ -65,7 +66,7 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
     <aside style={{...STYLE, width, height}}>
       <If condition={allowProjectFileSupport}>
         <div>
-          <ToolbarButton tooltip={translator.t("New project")} onClick={event => projectActions.newProject()}>
+          <ToolbarButton active={false} tooltip={translator.t("New project")} onClick={event => projectActions.newProject()}>
             <IconNewFile />
           </ToolbarButton>
 
@@ -130,6 +131,10 @@ export default function Toolbar({state, width, height, toolbarButtons, allowProj
         <IconConfigure />
       </ToolbarButton>
 
+      <If condition={[MODE_3D_FIRST_PERSON, MODE_3D_VIEW].includes(mode)}>
+        <ToolBarScreenshotButton state={state}/>
+      </If>
+
       {toolbarButtons.map((Component, index) => <Component mode={mode} key={index}/>)}
     </aside>
   )
